@@ -5,7 +5,7 @@ package Crypt::SRP;
 use strict;
 use warnings;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 $VERSION = eval $VERSION;
 #BEWARE update also version in URLs mentioned in documentation below
 
@@ -336,10 +336,9 @@ sub get_secret_S {
 }
 
 sub compute_verifier {
-  my ($self, $Bytes_I, $Bytes_P, $Bytes_s) = @_;
-  $Bytes_s = $self->_unformat($Bytes_s);
-  # do not unformat $Bytes_I, $Bytes_P
-  $self->client_init($Bytes_I, $Bytes_P, $Bytes_s);
+  my ($self, $Bytes_I, $Bytes_P, $salt) = @_;
+  # do not unformat: $Bytes_I, $Bytes_P
+  $self->client_init($Bytes_I, $Bytes_P, $salt);
   return $self->_format($self->_calc_v);
 }
 
